<template>
  <el-dialog
    width="65%"
    title="IFS库存物料"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="part-dialog"
  >
    <div>
      <span>需求数量：</span
      ><span style="color:Red;">{{
        materialRow == null
          ? ''
          : materialRow.surplusQuantity - totalPlanMoveQuality
      }}</span>
    </div>
    <el-table
      class="ifs-stock-table"
      :data="ifsStockData"
      style="width: 100%;"
      height="450px"
      border
      @selection-change="ifsStockSelectionChange"
      stripe
      ref="ifsStockTable"
    >
      <el-table-column type="selection" width="55"> </el-table-column>
      <el-table-column type="index" width="50" label="序号"> </el-table-column>
      <el-table-column
        prop="partNo"
        label="零件号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="partDesc"
        label="零件描述"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="locationDesc"
        label="库位"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="batchNo"
        label="批次号"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="wdr"
        label="WDR"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="optaskNo"
        label="工单"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="available"
        label="可用库存数量"
        align="center"
        show-overflow-tooltip
      >
      </el-table-column>
      <el-table-column
        prop="planMoveQuality"
        label="计划移库数量"
        align="center"
      >
        <template slot-scope="scope">
          <el-input
            v-model="scope.row.planMoveQuality"
            @blur="blurChangeCallback(scope.row)"
          ></el-input>
        </template>
      </el-table-column>
      <el-table-column prop="unit" label="单位" align="center">
      </el-table-column>
      <el-table-column prop="engChgLevel" label="版本" align="center">
      </el-table-column>
    </el-table>
    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`saveSelectRow`"
        >确 定</el-button
      >
    </div>
  </el-dialog>
</template>
<script>
import { getIfsStock } from '@/api/warehouse/stock'
import { saveBatchPalletTransportsDetail } from '@/api/warehouse/pallettransports'
export default {
  components: {},
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    transportsRow: {
      type: Object,
      default: () => {
        return {}
      }
    },
    materialRow: {
      type: Object,
      default: () => {
        return {}
      }
    },
    optask: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      totalPlanMoveQuality: 0,
      ifsStockData: [],
      multiSelection: []
    }
  },
  methods: {
    ifsStockSelectionChange(val) {
      this.multiSelection = val
      this.checkQuality()
    },
    blurChangeCallback(row) {
      this.checkQuality()
    },
    checkQuality() {
      // 勾选合计校验，是否大于需求数量
      let flag = true
      let flagMsg = ''
      for (let i = 0; i < this.ifsStockData.length; i++) {
        if (
          this.ifsStockData[i].planMoveQuality == null ||
          this.ifsStockData[i].planMoveQuality == ''
        ) {
          flag = false
          flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量不能为空；'
        } else {
          if (!this.checkZero(this.ifsStockData[i].planMoveQuality)) {
            flag = false
            flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量不能为0；'
          } else {
            if (!this.checkPositive(this.ifsStockData[i].planMoveQuality)) {
              flag = false
              flagMsg = flagMsg + '第' + (i + 1) + '行，计划移库数量需为正数；'
            } else {
              if (!this.checkDecimal(this.ifsStockData[i].planMoveQuality)) {
                flag = false
                flagMsg =
                  flagMsg + '第' + (i + 1) + '行，计划移库数量最多六位小数；'
              } else {
                console.log(
                  'this.ifsStockData[i].planMoveQuality',
                  this.ifsStockData[i].planMoveQuality
                )
                console.log(
                  'this.ifsStockData[i].available',
                  this.ifsStockData[i].available
                )
                console.log(
                  this.ifsStockData[i].planMoveQuality >
                    this.ifsStockData[i].available
                )
                if (
                  this.ifsStockData[i].planMoveQuality >
                  this.ifsStockData[i].available
                ) {
                  flag = false
                  flagMsg =
                    flagMsg +
                    '第' +
                    (i + 1) +
                    '行，计划移库数量大于可用库存数量；'
                }
              }
            }
          }
        }
      }
      /* if (flag) {
        this.totalPlanMoveQuality = 0
        this.multiSelection.forEach((item) => {
          this.totalPlanMoveQuality =
            this.totalPlanMoveQuality + Number(item.planMoveQuality)
        })
        if (
          Number(this.materialRow.surplusQuantity) <
          Number(this.totalPlanMoveQuality)
        ) {
          flag = false
          this.$message.error('计划移库数量大于需求数量；')
        }
      } else {
        this.$message.error(flagMsg)
      } */
      if (!flag) {
        this.$message.error(flagMsg)
      }
      return flag
    },
    checkZero(value) {
      if (value == 0) {
        return false
      } else {
        return true
      }
    },
    checkPositive(value) {
      if (!/^[0-9]+.?[0-9]*$/.test(value)) {
        return false
      } else {
        return true
      }
    },
    checkDecimal(value) {
      if (
        !/(^[1-9]([0-9]+)?(\.[0-9]{1,6})?$)|(^(0){1}$)|(^[0-9]\.[0-9]{1,6}$)/.test(
          value
        )
      ) {
        return false
      } else {
        return true
      }
    },
    saveSelectRow() {
      this.isSubmit = true
      const flag = this.checkQuality()
      if (flag) {
        const transportsDetails = []
        this.multiSelection.forEach((item) => {
          transportsDetails.push({
            partNo: item.partNo,
            partDesc: item.partDesc,
            batchNo: item.batchNo,
            wdr: item.wdr,
            transferQuantity: item.planMoveQuality,
            fromIfsLocationNo: item.locationNo,
            transportsMaterialId: this.materialRow.id,
            transportsId: this.transportsRow.id,
            operationTaskId: item.optaskId,
            operationTaskNo: item.optaskNo,
            unit: item.unit
          })
        })
        if (transportsDetails.length > 0) {
          saveBatchPalletTransportsDetail(transportsDetails)
            .then((response) => {
              const resData = response.data
              if (resData.code === 0) {
                this.innerVisible = false
                this.$message.success('添加移库明细成功')
                this.$emit('refreshDataList')
              } else {
                this.$message.error('添加移库明细失败')
              }
              this.isSubmit = false
            })
            .catch(() => {
              this.isSubmit = false
            })
        } else {
          this.$message.error('请选择IFS库存物料')
          this.isSubmit = false
        }
      } else {
        this.isSubmit = false
      }
    },
    initData() {}
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.initData()
        this.ifsStockData = []
        this.$nextTick(() => {
          // 根据零件号查询ifs物料库存
          const queryParam = {
            partNo: this.materialRow.partNo
          }
          getIfsStock(queryParam).then((response) => {
            const resData = response.data
            if (resData.code === 0) {
              const dataList = resData.data
              if (dataList && dataList.length > 0) {
                dataList.forEach((item, index) => {
                  this.ifsStockData.push({
                    id: index + 1,
                    partNo: item.PART_NO,
                    partDesc: item.PART_DESC,
                    locationDesc: item.LOCATION_DESC,
                    locationNo: item.LOCATION_NO,
                    batchNo: item.LOT_BATCH_NO,
                    wdr: item.WAIV_DEV_REJ_NO,
                    available: Number(item.QTY_AVAILABLE),
                    unit: item.UNIT_MEAS_DESC,
                    engChgLevel: item.ENG_CHG_LEVEL,
                    planMoveQuality: Number(item.QTY_AVAILABLE),
                    optaskNo: this.optask != null ? this.optask.optaskNo : null,
                    optaskId: this.optask != null ? this.optask.id : null
                  })
                })
              }
            }
          })
        })
      }
    }
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
